{ config, pkgs, ... }:

{
  imports = [ # Include the results of the hardware scan.
    ./hardware-configuration.nix

    # GUI
    ../../modules/system/gui/plasma.nix
    ../../modules/system/gui/steam.nix
    ../../modules/system/gui/sunshine.nix

    # CLI
    ../../modules/system/cli/common.nix

    # Hardware
    ../../modules/system/hardware/firewall.nix
    ../../modules/system/hardware/garbage-collection.nix
    ../../modules/system/hardware/locale.nix
    ../../modules/system/hardware/nvidia.nix
  ];

  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];

    substituters = [
      "https://nix-community.cachix.org"
      "https://cache.nixos.org/"
    ];
    trusted-public-keys = [
      "nix-community.cachix.org-1:mB9FSh9qf2dCimDSUo8Zy7bkq5CX+/rkCWyvRCYg3Fs="
    ];
  };


  # Bootloader.
  boot.loader.efi.canTouchEfiVariables = true;
#  boot.loader.grub = {
#    enable = true;
#    efiSupport = true;
#    device = "nodev";
#  };
  boot.loader.systemd-boot.enable = true;

  networking.networkmanager.enable = true;

  networking.hostName = "xv-desktop"; # Define your hostname.
  networking.interfaces.enp7s0.wakeOnLan.enable = true;

  users.users.xeovalyte = {
    isNormalUser = true;
    description = "Timo Boomers";
    extraGroups = [ "networkmanager" "wheel" "dialout" "fuse" ];
  };

  services.displayManager.autoLogin = {
    enable = true;
    user = "xeovalyte";
  };

  systemd.services."getty@tty1".enable = false;
  systemd.services."autovt@tty1".enable = false;

  system.stateVersion = "24.05";

}
